package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.32.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.32.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@("`0`````````````#``@````!````````'```````````0```````
M`*?H(```!P!``#@`"0!``!H`&0````8````$`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0```````">
MH````````)Z@````````GJ``````````'``````````<``````````%P```#
M````!`````````(X`````````C@````````".``````````8`````````!@`
M````````"`````$````%````````````````````````````````````````
MGKP```````">O````````0```````0````8```````"?W````````9_<````
M```!G]P````````#M````````!04```````!```````"````!`````````-H
M`````````V@````````#:`````````(``````````@``````````"&1TY5$`
M```&````````````````````````````````````````````````````````
M```````09'3E4@````0```````"?W````````9_<```````!G]P`````````
M)``````````D``````````$`````````````````````````````````````
M````````````````````````````````````"````P`"```#````````````
M```!``````$H````````\@`#\@`````````````````````````````````"
M(%`!*````````+```````````````````````````````````````B!0`2@`
M``````"R#P`\``````````````````````````````````(@4`$H````````
M\O\'_``````````````````````````````````"(%`!*````````+,___P`
M`````````````````````````````````B!0`2@```````"R`P`,````````
M``````````````````````````(@4`$H````````L```````````````````
M```````````````````"(%```````````0````````,4``````````$`````
M```#'P`````````/````````!'(`````````#````````!>P``````````T`
M``````!>T``````````$````````!6@`````````!0```````!)P````````
M``8````````(F``````````*````````!)``````````"P`````````8````
M`'```#4```````&<2``````````5`````````````````````P```````:!@
M`````````!$````````7```````````2`````````(``````````$P``````
M```0`````'````$``````````0````!P```%``````````(`````<```!@``
M`````````````'````H`````````(`````!P```1`````````&D`````<```
M$@`````````9`````'```!,`````````)``````````8````````````````
M;___^P`````(```!````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````&$```!I````
M```````````4````4P``````````````8P``````````````*@```#<`````
M````/````%P````;`````````$4````"````"0```#,````?````"````#``
M``````````````````!6````(@```#H``````````````!,````D````1P``
M````````````'0```#4````I````4@`````````N````/0```#8````6````
M'@```"L`````````/@```!<`````````2````$(`````````30````\````E
M````9````"<``````````````$$`````````2@```%X````1````````````
M```O````.0````````!,````)@```#@````````````````````8````(P``
M`!4````@````&0```%<`````````+0````,````````````````````:````
M`````"P````2`````````&@````H````,0``````````````````````````
M````9P``````````````!@``````````````6P````````!A````````````
M``````````````````!=`````````$8```!9````$````$\```!4````````
M````````````#@````P`````````-````!P```!`````7P````L`````````
M(0```#\````R``````````<```!0``````````````!B````````````````
M````90```#L`````````#0``````````````0P```$D```!.````````````
M`````````````$L```!$````````````````````!0``````````````40``
M````````````9@```%4`````````````````````````6@```%@````*````
M`````````````````````&`````$````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````````````#```(````````%[``````````````
M`P42```)````````&0`````````"4```!!@0```)````````&0``````````
M````!!\2```)````````'0``````````2````VD2```)````````+K@`````
M````2````"H2```+````````7M``````````"````PLA````````````````
M`````````````U,2```)````````)N@````````!2```!"@2```)````````
M*#``````````&```!#D2```)````````'`@``````````````X02```)````
M````+P`````````!%````]P2```)````````,!0````````(F````[02```(
M````````%[``````````"`````$3`/_Q``````````$``````````````S42
M```)````````)A``````````6```!$42```)````````'```````````````
M!$T0```5```````!HY```````````````Y82```)````````+D0`````````
M=````ST2```)````````.*P````````##````[H2```)````````5OP`````
M```!P````PH1````````````````````````````!`(1```1```````!H$``
M````````"```!$82```)````````'````````````````_42```)````````
M*J0`````````+```!%,0```1```````!H```````````````!%H0```5````
M```!HY```````````````[$2```)````````5G0`````````B````^D2```)
M````````*M`````````!1````\\2```)````````+!0````````",````!(1
M```2```````!H%``````````````!&80```4```````!HY``````````````
M`Z02```)````````*$@````````"7````\42```)````````6+P````````"
M$```!&T0```5```````!L_``````````````!`P2```)````````.[@`````
M````K````+D2````````````7K```````````````,`2````````````7J``
M`````````````-$2````````````7I```````````````*\2````````````
M7H```````````````-@2````````````7G```````````````N$2````````
M````7F```````````````-\2````````````7E```````````````M,2````
M````````7D```````````````/,2````````````7C```````````````)P2
M`````````````````````````````?H2````````````7B``````````````
M`+02````````````7A```````````````/X2````````````7@``````````
M`````002````````````7?```````````````(L2````````````````````
M`````````'L2`````````````````````````````142````````````7>``
M`````````````&P2````````````7=```````````````1L2````````````
M7<```````````````2`2````````````7;```````````````3,@````````
M`````````````````````4T2````````````7:```````````````&,2````
M````````79```````````````L,2````````````78```````````````5,2
M````````````77```````````````5@B````````````````````````````
M`6XB`````````````````````````````%02````````````76``````````
M`````7T1`````````````````````````````LL2````````````75``````
M`````````8\2````````````74```````````````PP1````````````````
M`````````````O@2````````````73```````````````$82````````````
M72```````````````WL2````````````71```````````````9@2````````
M````70```````````````:82````````````7/```````````````:T2````
M````````7.```````````````#L2````````````7-```````````````;T1
M`````````````````````````````<@2````````````7,``````````````
M`<\2````````````7+```````````````MH2````````````7*``````````
M`````=0@`````````````````````````````?`2````````````7)``````
M`````````?D2````````````7(```````````````#`2````````````7'``
M`````````````?\2````````````7&```````````````@<2````````````
M7%```````````````2P2````````````7$```````````````@\2````````
M````7#```````````````A82````````````7"```````````````B(2````
M````````7!```````````````ND2````````````7````````````````KL2
M````````````6_```````````````BD2````````````6^``````````````
M`C`2````````````6]```````````````C<2````````````6\``````````
M`````CTB`````````````````````````````E42````````````6[``````
M`````````FH2````````````6Z```````````````GL2````````````6Y``
M`````````````H02````````````6X```````````````HL2````````````
M6W```````````````I<2````````````6V```````````````!P2````````
M````6U```````````````I\1`````````````````````````````JP1````
M`````````````````````````K,2````````````6T````````````!?1%E.
M04U)0U],24Y+24Y'`%]?4DQ$7TU!4`!097)L7W-Y<U]T97)M`%]F:6YI`'!E
M<FQ?<&%R<V4`<&5R;%]A;&QO8P!P97)L7V1E<W1R=6-T`%!E<FQ?<WES7VEN
M:70S`'!E<FQ?<G5N`'!E<FQ?8V]N<W1R=6-T`&)O;W1?1'EN84QO861E<@!0
M97)L7V%T9F]R:U]L;V-K`%!E<FQ?871F;W)K7W5N;&]C:P!P97)L7V9R964`
M9V5T=6ED`%]?<W1A8VM?8VAK7V9A:6P`<W1R;&5N`&UE;6-P>0!P=&AR96%D
M7V=E='-P96-I9FEC`%!E<FQ?;F5W6%,`;6MD:7(`7U]E<G)N;U]L;V-A=&EO
M;@!R;61I<@!R96%D`%!E<FQ?<V%F97-Y<VUA;&QO8P!?251-7W)E9VES=&5R
M5$U#;&]N951A8FQE`&-L;W-E`&5X:70`7U]R96=I<W1E<E]F<F%M95]I;F9O
M`%]?8WAA7V9I;F%L:7IE`%]?<W1A8VM?8VAK7V=U87)D`')E861L:6YK`%!E
M<FQ?<W9?<V5T<'8`<W1R8VAR`%!E<FQ?9W9?9F5T8VAP=@!03%]T:')?:V5Y
M`'-T<G-T<@!O<&5N`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!C;&]S
M961I<@!L<W1A=`!S=')N8VUP`&UE;6UO=F4`=6YL:6YK`%!E<FQ?;6=?<V5T
M`&UE;7-E=`!S=')C;7``9V5T<&ED`&QS965K`%]?9&5R96=I<W1E<E]F<F%M
M95]I;F9O`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?;F5W6%-?9FQA9W,`
M<VYP<FEN=&8`86-C97-S`%!E<FQ?9V5T7W-V`')E86QL;V,`4$Q?9&]?=6YD
M=6UP`'-T9&5R<@!O<&5N9&ER`')E861D:7(`9G!R:6YT9@!S=')N8W!Y`'-T
M<G1O:P!S=')D=7``<W!R:6YT9@!P=&AR96%D7V%T9F]R:P!?7VQI8F-?<W1A
M<G1?;6%I;@!?7V5N=FER;VX`;&EB<&5R;"YS;P!L:6)C+FUU<VPM;6EP<S8T
M+G-O+C$`>'-?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V-U<G)E
M;G1?97AE8U]P<F]C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]S
M971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R7V9I;F1P<F]G`'-H85]I
M;FET`'-H85]U<&1A=&4`<VAA7V9I;F%L`'!A<E]I;FET7V5N=@!P87)?;6MT
M;7!D:7(`<&%R7V1I<FYA;64`<&%R7V)A<V5N86UE`&UY7W!A<E]P;`!P87)?
M8VQE86YU<`!?9G1E>'0`7W-T87)T7V,`<&%R7V-U<G)E;G1?97AE8P!?<W1A
M<G1?9&%T80!?7W-T87)T`%]F8G-S`%]F9&%T80!?7V)S<U]S=&%R=`!?961A
M=&$`7V5N9``O=7-R+VQI8B]P97)L-2]C;W)E7W!E<FPO0T]210``````````
M```````````````````!H``````````2`P```````:`(````````$@,`````
M``&@$````````!(#```````!H!@````````2`P```````:`@````````$@,`
M``````&@0````````!(#```````!HX@````````2`P``````````````````
M`````````````````````````````````````````````&>]_^#_O``0_[\`
M&``````$$0`!``````.`$"4\'``")YP(B`.?X"W?F8!H`R#X"0`````$$0`!
M``````.`$"4\'``")YP(9`.?X"W?F8#X`R#X"0````#?O``0W[\`&`/@``AG
MO0`@````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````&>]_[#_O`!`/!P``@.9X"UGG`=0WYF!Z/^E`!#_I@`(KZ0`
M'&>F``AGI0`09Z0`'/^_`$C_L``@_[,`./^R`#`#(/@)_[$`*-^&@5C?A(&`
MWYF"N`#`*"4#(/@)WY""2-^"@R"00@``%$``$]^9@4#?F8)``R#X"0``````
M0"`EWX*`.!2```3\1+/HWYF!T`,@^`DD!``!WYF!F`,@^`D`````WYF!0`,@
M^`F.!```H$`*H=^9@4`#(/@)C@0``(X$``"00P3RWYF!0#1C``(#(/@)H$,$
M\H^D`!R00P3R)(8``R2$``3?F8&H-&,``0`$(/B@0P3R`R#X"?^F``#?I0`0
M`$`X)=^"@#B/J``<_$>SX-RB``#?I@``_.(``-^"@%@``!@E9$)BR/SB``C?
M@H#HW$(``/SB`!#?@H!89$)BT/SB`!@``Q``9&,``21"``0``R````(0^`"(
M("H4@``V`.(0+=^1@#C?A8!8WYF"@-XDL^@``$`E9*4F:`,@^`G\0```%$``
M!0!`@"7?F8'``R#X"=XDL^@`0(`EWYF"&-XDL^@#(/@)WY.`6-^$@%AF<R`L
M`F#()0,@^`EDA&`P%$``#]^9@2C?DH`XWD*SV!1```7?A(!8`F#()0,@^`ED
MA%^X_D*SV-Y$L]@0@``#WYF`\`,@^`D`````WYF!*`,@^`G>)+/HWYF#&`,@
M^`D`````W[\`2-^\`$#?LP`XW[(`,-^Q`"@"`!`EW[``(`/@``AGO0!0``,@
M^`"D("W<A```$`#_O_Q$````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````01``<``/`E_______]^[C_______W\L/_______>,8
MW_P```/\X"\#H"`EW^4`$`"\*"W?^0`(`SS(+20!__`#H>@D`R#X"0``````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````````!G
MO?_P_[P``#P<``(#F>`M9YP#4-^9@A#?B(`@WX>`*(R%``1DA@`(WX2`,/^_
M``@#(/@)``!()=^_``C?O````^``"&>]`!```````````#P#``(`>1@M9&,#
M`-QD@#C<8H!`9(2@6!!$``7<>8)H$R```P`````#(``(``````/@``@`````
M/`,``@!Y&"UD8P+(W&2`.-QE@$!DA*!8`*0H+P`%$/L`!2_^`*(H+0`%*'L0
MH``%W'F!L!,@``,``````R``"``````#X``(``````````!GO?_0_[P`(#P<
M``(#F>`M9YP">/^S`!C?DX`X_[\`*))BHY#_L@`0_[$`"!1``"O_L```WX*!
MX!!```3?@H!(WYF!X`,@^`G<1```WX.`.-^1@%!D8Y_PWY"`.`(CB"_>`J.8
M`!&(^]^$@#AF,?__`%$8*V22G_`08``-WYF`6&1"``$```````(8^`)#&"W<
M>0```R#X"?X"HYC>`J.8`%$8*Q1@__AD0@`!WYF`6&<Y'5`#(/@)`````-^"
M@N`00``$WYF"X-^$@#@#(/@)9(2?W"0"``&B8J.0W[\`*-^\`"#?LP`8W[(`
M$-^Q``C?L````^``"&>]`#``````9[W_\/^\```\'``"`YG@+6><`7C?@H'8
M$$``!_^_``C?A8`XWX2`.-^9@=ADI:.@`R#X"62$G]S?F8!8W[\`"-^\``!G
M.1V(`R``"&>]`!```````````&>]_[#_O`!`/!P``@.9X"W_L0`0_[\`2/^V
M`#C_M0`P_[0`*/^S`"#_L@`8_[``"&><`2`0@``?``"()=^"@@C<5```$H``
M&P"`F"4`H*@E`(`P)20#`#V`P@``%$``(0#3@"\`$(```H"0)206`#W>40``
M$B``#]^9@H@"`#`E`F`H)0,@^`D"("`E%$``&0(P$"V`0@``%%8`%@`````"
M5)`O`!*0^V80``&NL@```C"(+=^_`$C?O`!`W[8`.-^U`##?M``HW[,`(-^R
M`!C?L``(`B`0)=^Q`!`#X``(9[T`4!!#_]\`````$`#_VF3&``$0`/_>9E(`
M"&>]_]#_O``@/!P``@.9X"UGG``D_[``&-^9@%C?D('P_[\`*-X"``!GI0`$
M9SD?,/^B``@#(/@)`````-^D``C>`P``$(,`!-^_`"C?F8$8`R#X"0````#?
MO``@W[``&`/@``AGO0`P9[W_L/^\`$`\'``"`YG@+6><_[S_L0`HWY&!\/^S
M`#C_L@`P_[``(/^_`$C>(@``WY"`6-^3@@C_H@`89[(`%&80'S`"0"@E`@#(
M)0,@^`G_I``(%$``"-^D``C?HP`8WB(``!!B``W?OP!(WYF!&`,@^`D`````
MCZ(`%``"&/C>8@```$,0+=Q#``@08/_M_$,``!``__QD0@`(W[P`0-^S`#C?
ML@`PW[$`*-^P`"`#X``(9[T`4&>]_L#_O`$P/!P``@.9X"UGG/\$_[4!&-^5
M@?#_OP$X_[<!*/^V`2#_M`$0_[,!"/^R`0#_L0#X_[``\-ZB``#_H@#H$(``
M&0````"`@@``$$``%@"`B"7?F8,P`R#X"0`````00``1`$"0)=^3@%C?E(!8
MWY:`6&9S7U!FE"%,WYF"P`,@^`D"0"`E%$``#M^9@LC?F8)P`R#X"0)`("7?
MF8&0`R#X"0(@("7?HP#HWJ(``!!B`#W?OP$XWYF!&`,@^`D`````9%``$P)@
M*"4#(/@)`@`@)1!`_^K?F8+`WYF"R&;%7U@#(/@)`@`@)1!`_^3?F8+`WYF!
M(`,@^`D"("`EWYF!(`(`("4#(/@)`$"X)=^9@I@"XA`M``(@``,@^`DDA``"
MWX6`6-^9@3@`0"`E`@`X)0(@,"5DI5]@`R#X"?^B``C?I``(WYF!8`,@^`EG
MI0`8)`/__Q!B``[?I``(CZ(`."0#0``P0O``%$,`"0`````"@,@E`R#X"0``
M``#?F8%H`R#X"=^D``@0`/^\WYF"P-^9@J`#(/@)_Z0`"!``__<`````W[P!
M,-^W`2C?M@$@W[4!&-^T`1#?LP$(W[(!`-^Q`/C?L`#P`^``"&>]`4!GO?\`
M_[P`\#P<``(#F>`M9YS]+/^Q`.C?D8'P_[``X-^9@GC_OP#XWB(``&>E``@`
M@(`E_Z(`V`,@^`D`````%$``%(^C`"@D!4``,&/P`!!E``0`8"`E-`.@`!2#
M``8`````WYF#`"0%``(#(/@)`@`@)2Q"``'?I`#8WB,``!"#``;?OP#XWYF!
M&`,@^`D`````$`#_^```$"7?O`#PW[$`Z-^P`.`#X``(9[T!`&>]_Z#_O`!0
M/!P``@.9X"UGG/Q\_[,`,-^3@?#_L0`@_[``&/^_`%C_M@!(_[4`0/^T`#C_
ML@`HWF(``("C``#_H@`()`(`/0"`B"448@`"`*"`)62P``'?F8$@`R#X"0(`
M("7?F8!89Z4`!`(@("5G.1\P`R#X"0!`H"400``3`$"0)=^9@2`#(/@)`$`@
M)0!4$"L40``F`B`8)8("``!F$``!9E(``11`__RB0O__WZ,`"-YB```08@!6
MW[\`6-^9@1@#(/@)`````-^5@@@``)`EWK8```+`$"7<0P``%&``/&1"``C?
M@H`X)D0``HQ#L]`08``Y``0@^-^9@Q``@"@E`R#X"0+`("400/_H_J(``"9"
M``$``ACXWJ(```!#$"W\0```K[(`!`(@&"4D!``]@&(``!!```./L@`$%$0`
M,@````#?E8((`'$8+]^9@I@``Q@`9H0``@`2$/@`9"`MWK(```,@^`D"0I`M
M$$#_S_Y"``"/H@`$)`4`/0`"&/C>H@```$,0+=Q"``""(P``9C$``:!#````
M0"`E$&```V1"``$49?_Y`````"0#`#V@@P``@@,``&80``%D0@`!%&#__*!#
M__\0`/^X`````!``_\$F4@`!WYF"F"0#``$#(/@)K$.ST!!`_[``0"`EWYF"
MD``2,/@#(/@)`L`H)1``_\/^H@``$`#_R61C``'?O`!0W[8`2-^U`$#?M``X
MW[,`,-^R`"C?L0`@W[``&`/@``AGO0!@9[W_\/^\```\'``"`YG@+6><^D#?
M@H)(_[\`"-^9@4`#(/@)C$0``-^'@'#?A8!8WX:!B-^9@5!DYYZ(9*5?:`,@
M^`D`0"`EW[\`"-^\```#X``(9[T`$&>]_^#_O``0/!P``@.9X"UGG/GH_[``
M"-^0@DC_OP`8WYF!0`,@^`F.!```WYF`>`,@^`D`0"`EWYF!0`,@^`F.!```
MWXB`6-^%@%C?AH"`WYF"\&4(8L```$@E`0`X)62E7X@#(/@)`$`@)=^_`!C?
MO``0W[``"`/@``AGO0`@9[W?H/^\(%`\'``"`YG@+6><^6C_LR!(WY.!\-^9
M@M#_OR!8_[(@0/^Q(#C_L"`PWF(``/^B("@#(/@)`````-^(@%C?AH!8WYF"
M^&>D`!AE"%^@`$`X)63&7Z@D!1`!`R#X"?^D``@D`___%$,`"=^D``@``"`E
MWZ,@*-YB```08@`IW[\@6-^9@1@#(/@)`````"Q#$`$$;```!$#_]=^9@@!G
ML1`@)`80``,@^`D"("@E``*```8`_^X"`)`EWYF"F`,@^`DF!``!$$#_Z0!`
M("4`41`K$$``!`(D$"L`DA`M`B(`,P(D$"L00``$WYF!,`(P$"T`@@`SWYF!
M,`(`,"4"("@E*E(0`@9,```#(/@)``````!0@"T`0"`E$`#_U:(```#?O"!0
MW[,@2-^R($#?L2`XW[`@,`"`$"4#X``(9[T@8#P#``(`>1@M9&/X(-QY@(@#
M(``(`````&>][K#_O!$X/!P``@.9X"UGG/@(_[<1,/^P$/C?EX'P`("`)=^9
M@%C?A(!8_[\12/^T$1C_LQ$0_[X10/^V$2C_M1$@_[(1"/^Q$0#>X@``9(1?
MN&<Y("P`H)@E_Z(0Z`,@^`D`````WYF","0%`"\"`"`E`R#X"0!`H"400``.
MWYF!(-^$@%C?F8!8`@`H)6<Y(]0#(/@)9(1?R-^C$.C>X@``$&(`8-^_$4C?
MF8$8`R#X"0`````"`"`E`R#X"=^2@%C?F8%(9D5?V`)@("4#(/@)``*(`-^5
M@%C?EH!8`$#P)=^"@%AFM5]09M9?X/^B``@3P/_DWX2`6(/"```40``"````
M``*@\"42@``,WYF"R`/`*"4#(/@)`H`@)11```C?F8$@WYF!2&9%7]@#(/@)
M```@)1``_^X`0/`EWYF!(`,@^`D#P"`E)`0`+P`"$``D0___`\,8+8!E```0
MI``4)$;__R8C``$`8A`A*$(0`!!`_\/?H@`(WYF"^&>S`.@"`$@E`L!`)0/`
M."5D1E_H)`40``,@^`D"8"`E)$(``2Q"$`$40``%WYF!8````#2@8```$`#_
MY@#`$"5GI0`8`R#X"0)@("440/_6CZ(`.#0#@``P0O``%$/_T]^9@4C?F8,`
M)`4``0,@^`D"8"`E%$#_S=^9@4C?A(!8WYF`6`)@*"5G.2/4`R#X"62$7\C?
MF8)@`R#X"0)@("40`/^>`$"`)=^^$4#?O!$XW[<1,-^V$2C?M1$@W[01&-^S
M$1#?LA$(W[$1``(`$"7?L!#X`^``"&>]$5``@!`E)`4`+X"#```48``#````
M``/@``@`````%&7_^F2$``$0`/_X`(`0)6>]_^#_O``0/!P``@.9X"W_OP`8
M_[``"!"```1GG/6`@((``!1```L`@(`EWX2`6-^9@F!DA%]0`R#X"0````#?
MOP`8W[P`$-^P``@#X``(9[T`(-^9@2`#(/@)`````"0#`"]D0O__`@(0+0("
M("L0@``H`````(!$```0@P`A`````"0#`"\"`B`K$(``(0````"`1```%(,`
M'&1%__\D`P`O9$+__P("("L0@``&`%`P+X!$```0@__[9$+__V1"``$`4#`O
M9,,``BQC$`$08/_;```0)0(`*"7?D(`XWYF!^&3&``%F!*/0+,(0`01,```#
M(/@)`````!``_]!F`J/0$`#_V61"__\0`/_>`*`0)18"_^,D`P`O@@,``"0"
M`"\48@`$WYF"8-^$@%@0`/_!9(1?4-^$@%@0`/^^9(1?X&>]_X#_O`!P/!P`
M`@.9X"UGG/0\_[4`8-^%@'#?E8'P_[\`>-^9@3#_M@!H_[0`6/^S`%#_L@!(
M_[$`0/^P`#@D!@`B9*6>8-ZB```#H"`EWY"`6/^B`"@#(/@)9A`@E-^$@%@"
M`,@E9(1?\`,@^`G?DX!8WX2`6`(`R"5DA&```R#X"=^4@%C?A(!8`@#()62$
M8`@#(/@)WY*`6-^$@%@"`,@E9(1@&`,@^`G?EH!8`@#()69D8"`#(/@)WY&`
M6-^$@%@"`,@E9(1@,`,@^`EF,2`L`@#()0,@^`EFA%^X`@#()0,@^`EF1&!`
M`@#()0,@^`EFQ&!0WX2`6`(`R"4#(/@)9(1@8-^$@%@"`,@E9(1?R`,@^`G?
MD(!8WX2`6`(@R"5DA&!P`R#X"680(]000``$`@#()0!`*"4#(/@)9L1@4-^$
M@%@"(,@E`R#X"62$8(@00``%`$`H)=^$@%@"`,@E`R#X"62$7R#?A(!8`B#(
M)0,@^`EDA&"@9H1?N!1```@`0"@EWX2`6`(@R"4#(/@)9(1@L!!``!$`0"@E
M9D1@0`(`R"4#(/@)`````-^%@%AF9&`@`@#()0,@^`EDI6#8WZ,`*-ZB```0
M8@`.W[\`>-^9@1@#(/@)`````-^%@%C?F8*()`8`"F2E8,@#(/@)9Z0`$11`
M_^UGI0`;$`#_Z&9$8$#?O`!PW[8`:-^U`&#?M`!8W[,`4-^R`$C?L0!`W[``
M.`/@``AGO0"`9[W_X/^\`!`\'``"`YG@+6><\@S_L``(WY"`."0"__^.`Z`P
M%&(`#?^_`!C?A(!8WYF`6&<Y("P#(/@)9(1@0!!```4``!@E@$(``!!```(X
M0@`P``(8*ZX#H##?OP`8C@*@,-^\`!#?L``(`^``"&>]`"!GO?_P_[P``#P<
M``(#F>`M9YSQF-^9@1#_OP`(`R#X"0````#?F8(@`R#X"0!`("400``"W[\`
M"-Q"``#?O````^``"&>]`!!GO?_0_[P`(#P<``(#F>`M9YSQ4/^S`!C?F8!8
MWY.`6/^Q``AG.2`L`("()69D8.#_OP`H_[(`$`,@^`G_L````F`@)1!```4"
M("@E`$"`)8!"```40``,WYF"4&2$8.#?F8!8W[\`*-^\`"#?LP`8W[(`$-^Q
M``C?L```9SDCU`,@``AGO0`P`R#X"0(`("440``9W[\`*-^9@2`#(/@)`B`@
M)=^9@2`"`"`E`R#X"0!`D"7?F8*8`D(0+0,@^`ED1``"WX>`6-^%@%C?F8$X
M9*5?Z`!`("4"`$`E9.=?V`(@,"4#(/@)`$"0)0)`*"40`/_;9F1@X-^\`"#?
MLP`8W[(`$-^Q``C?L````^``"&>]`#!GO8`0_[Q_V#P<``(#F>`M9YSP//^W
M?]#?EX'P_[]_Z/^V?\C_M7_`_[1_N/^P?YC_OG_@_[-_L/^R?ZC_L7^@9[W^
M``"`J"5GI``0WN(``#0#@7@`9!@M_&(``#0"@8``1!`M/!#__P!0@"W?@H!8
MWX6`.&1"8/C^`GZ`WX*`6-^9@3!D0E]0)`8`,&2EH`!F!'ZP_@)^B`,@^`G^
M`'Z0WX*`6-^6@%AD0F$`_@)^F-^4@%C?@H!89M8@+&1"80AFA%^X`L#()?X"
M?J`#(/@)_@!^J!!``!;?F8"0`$"`)8!"```00``2`````-^9@)@#(/@)`@`@
M)=^9@F`#(/@)`@`@)0!`@"5GHP`0-`*!>`!#$"W<0P``WN(``!!B`=`"`!`E
MWYF!&`,@^`D``````R#X"0`````40``:`$"`)3P1__\T`H&`9Z,`$&8Q?I@`
M0Q`M`%&(+=XD```4@``$`L#()=^0@%@0```.9A!@\`,@^`D`````%$```P!`
M("40`/_U9C$`"(!"```00/_\WYF"8`,@^`D`````$$#_^`!`@"7?F8$@`@`@
M)0,@^`G?DX!8WYF"F``"('ADA``!`R#X"69S81@`0)`E`$"()8(&```4P`!;
MWYF!.-^3@%@\$?__-`*!@&>C`!!F,7ZP`$,0+0!1B"UF<R,DWC```!(``!`"
MP,@E`R#X"0(`("400`!3`$"`)8!"```00`!0`F#()0,@^`D"`"`E$$#_\V8Q
M``C?F8)@`R#X"0(`("4`0(`EWYZ`6#P1__\T`H&`9Z,`$&8Q?H``0Q`M`%&(
M+6?>(R06```(WYF!(-XS```28``%`````()B```40``Z`\#()=^9@2`#(/@)
M`@`@)=^9@2`"0"`E`R#X"0!`B"7?F8*8`B(@+0`$(``DG@0$`R#X"0/`("4"
M0$@EWXB`6-^2@%C?A8!8WYF!.&4(82!F1U_@`@`P)62E82@`0"`E`R#X"0!`
MB"7?F8%P)`4!P`,@^`D"("`E)`/__Q1B`"/?F8%X`R#X"0````",2```)`(`
M$1$"`!YGHP`0WX*#*-^%@%C>I@``W$0``-^9@<@"(#@E`R#X"62E83@0`/]R
M``"`)0(@("4PQ@#_`F`H)0,@^`EF$``!$`#_G68Q``(0`/^F9C$`"`,@^`D"
M8"`E$$``!-^9@F`#(/@)`F`@)0!`@"40`/^W9C$`"&>C`!`\$/__-`*!@-^9
M@G@`0Q`M9@5^X`!%*"T#(/@)`B`@)1!```L`0)@EWX*#*-^%@%C>I@``W$0`
M`-^9@<@"(#@E`R#X"62E87@0`/_8`````&>C`!`T`H&``$,0+0!0@"V.`G\`
M)`-``#!"\``40__OWX*#*-^9@1".`W\(`R#X"?^C``C?HP`(``(0`!1B_^??
M@H,HC@)_`"0#`<`P0@'_%$/_XM^"@RC?F8*8`R#X"0/`("7?A(!8`L#()62$
M8=`#(/@)`$"`)11``'\`0"`EWK8``-^9@2`#(/@)`L`@)0`"$```0/`E*$(`
M!!1``"/?F8"@WX6`6-^9@LAGQ/_\9*5AV`,@^`D"Q"`M%$``&]^9@*`D`@`$
M$\(`!B?>__L"WO`M@\,``"0"`"\48@`3`````-ZU``@2H``/WYF!(`,@^`D"
MH"`E+$,`!!1@``O?F8"@WX6`6-^9@LAD0O_\9*5AX`,@^`D"HB`M%$```]^9
M@*`"H+`EWYF`H`,@^`D`````%$``HM^%@%C?F8)8```H)0,@^`D"P"`E$$``
MFP!`J"7?F8+8)`8``B0%_^X`0"`E`R#X"3P3__]GHP`0-`*!@`!#$"UF=G_X
M`%:P+=^9@:`D!@`&`L`H)0,@^`D"H"`E9Z,`$#0"@8``0Q`M`%,0+9!#?_@4
M8``^WYF"V)!#?_DD!`!#%&0`.P``,"6017_Z)`0`012D`#<`````D$1_^Q2#
M`#0D`P!(D$1__!2#`#(``"@ED$-__20"`$448@`N`````"0&``(D!?_&`R#X
M"0*@("7?F8&@)`8`*0+`*"4#(/@)`J`@)=^)@%@"P$`E92EBP-^%@%C?F8$X
M9D=?X`(@,"5DI6'H`R#X"0(`("7?F8%H`R#X"0(@("7?F8!8`@`H)6<Y(]0#
M(/@)9H1?N-^9@)@#(/@)`@`@)1``_JYGHP`0WYF"8`,@^`G>M@``WYF`J`+`
M("4#(/@)`$`H)11`_WL`0+`E$`#_>=ZV`````#`E```H)0*@("4#(/@)/!/_
M_]^9@+`#(/@)9GY_^&>C`!``0+`E-`*!@`!#$"T`7O`MWYF!H#0&@``#P"@E
M`R#X"0*@("4``C``',``+=^9@+C?F8&X`J`@)0,@^`EF<W^P9Z,`$#0"@8``
M0Q`M`%.H+=^9@,`"P"@E`J`@)0,@^`EF<P`8WX6`6#0"@8!GHP`0`$,0+0!3
MF"T``/`E/!;__V2E81@"OA`MWYF!.)!&```"8"`E_Z4`"`,@^`EGW@`!)`,`
M%-^E``@7P__V9G,``F>C`!`T`H&``$,0+0!6$"W?B8!8H$!_\#0"@8!FR'_(
M`$,0+64I8L`0`/^A`$A`+0/`*"4#(/@)`L`@)1``_\G?F8&@WX6`6-^$@%C?
MF8!89*5@V&2$8$!G.2/4`R#X"=^5@%C?F8+0WY:`6`,@^`DD'O__WX6`6-^9
M@3AFJ6+``$!`)69'7^`"(#`E9*5A^`(`("5FM6+``R#X"6;68@C?F8%P)`4!
MP`,@^`D"`"`E%\+_AM^9@7@#(/@)`````"0#`!&,0@``%$/_@-^9@M`#(/@)
M`````-^9@3@F:0`!`J!0)0!`0"5F1U_@`B`P)0+`*"4"`"`E`R#X"0$@F"40
M`/_HWYF!<&>]`@#?OW_HW[Y_X-^\?]C?MW_0W[9_R-^U?\#?M'^XW[-_L-^R
M?ZC?L7^@W[!_F`/@``AGO7_P9[W_T/^\`"`\'``"`YG@+6><YZ3_L```WY""
M2/^_`"C_L@`0_[$`"/^S`!C?F8%`C@0```,@^`G?DH!8C@0``-^9@4``0(@E
M`R#X"692("S?A(!8DB,`N&2$8"`"0,@E`R#X":!#`+D00``')`,`,8!$```4
M@P`%WYF`R(!"``$00``%WYF!0-^9@,@#(/@)`````-^9@4`#(/@)C@0``-^%
M@%C?F8(X)`<``R0&``%DI6(@`R#X"0!`("400``9`$"()=^9@4`#(/@)C@0`
M`-XC`!#?AH!8W&4``-^9@B@`0"`E`R#X"63&8BC>(@`0W$(``(Q"``P``A6"
M,$(``1!```G?F8%``R#X"8X$``#>(P`0WYF"J-QE```#(/@)`$`@)=^9@4`#
M(/@)C@0``-^%@%C?F8(X)`<``R0&``%DI6(P`R#X"0!`("400``D`$"()=^$
M@%@"0,@E`R#X"62$7\@00``,`$"8)=^9@4`#(/@)C@0``-XC`!`"8#`EW&4`
M`-^9@B@#(/@)`$`@)1```!,`````WYF`B`,@^`D`````C@0``-^9@4`00``U
M`$"8)0,@^`D`````WB,`$-^9@BC<90```$`@)0,@^`D"8#`EWYF!:`,@^`D"
M8"`EWYF!0`,@^`F.!```C@0``-^9@4`#(/@)`$"()=^%@%C?F8,()`8``62E
M8C@#(/@)`$`@)=^&@%C?F8(H9,9B4`!`*"4#(/@)`B`@)8X$``#?F8%``R#X
M"=^0@#C?A(!8`D#()62$7[@#(/@)H$``N0(`B"440``2_@*SV-^"@#C?F8#0
M`R#X"=Q$L^`40``,_@*SV-^$@%C?F8+H`R#X"62$8E@#(/@)`````-^#@#C<
M9+/@WB,`$!``_[G<A@``WYF!<-XDL]@#(/@))`4!P`!`."4D`@`1$.(`#"3B
M``$L0@`"%$``"M^_`"C?@H`XWX2`6-Q"L^#>)K/8W$4``-^9@N@#(/@)9(1B
M@-^_`"C?O``@W[,`&-^R`!#?L0`(W[````/@``AGO0`P9[W_X/^\`!`\'``"
M`YG@+6><Y)C?F8#8_[\`&/^Q``C_L````R#X"0"`@"7?F8#@`R#X"0!`("7?
MF8"@`R#X"0!`B"400``4W[\`&!(``!(`````@@(``!!```_?A8!8WYF"4&2E
M82`#(/@)`B`@)18B``G?OP`8WYF`6-^\`!#?L0`(`@`@)=^P``!G.2%,`R``
M"&>]`"#?O``0W[$`"-^P```#X``(9[T`(````````````````&>]_4#_O`*P
M/!P``@.9X"UGG./@WXJ!\/^_`KC_LP*H_[("H/^Q`IC_L`*0W4(``&2#`#C_
MH@*(9Z(`"&2'`'@`0"@EW&8``&1C``@`!D`^``8P/``&,#[\J```_*8`"!3C
M__ADI0`09$8"`-Q%`$#<0P!H9$(`"`!E&";<10`(`&48)MQ%__@`91@F``,H
M>``#'_H`HQ@E``,8/``#&#X41O_R_$,`>-R,```\#5J"``P>^@`,$7@`0Q`E
MWZ,`"&6M>9G<BP`@W(<`$-R(`!@`;1@M``(0/-R)``@`:Q@M``(0/@!#$"T`
MZ!@F`&D8)`!H&"8`0Q`M``DWN``)&+H`PS`E``:`/``0@#[?HP`0`/#`)@,,
MP"0`;1@M``(0/``"$#X#!\`F`&@8+0,#P"T``BEX``(>^@"C*"4#!<`M``P8
MN@`,+[@`HR@E`,5P)M^F`!@!PG`D`,TP+0`8P#P`&,`^`,<P+0'0<"8!QG`M
M`!@9>``8-OH`9A@E`<-P+0`"'[@``A"Z`&(0)0"B&"8`!<@\WZ4`(``.<#P`
M#G`^`*TH+0`9R#X`>!@D`+"`+0`.-OH`>1@F``XI>`"F*"4`<!@M`&48+0`8
M+[@`&,"Z`+@H)=^X`"@``G@\`$40)@,-P"T`#W@^`$X0)``#&#P``Q@^`QG(
M+0!/$"8`61`M``/!>``#SOH#&<`E``Z'N``.<+H"#H`E`%@0+=^X`#``!3`\
M`+`H)@,-P"T`!C`^`*,H)``"$#P``A`^`P]X+0"F*"8``L;Z`*\H+0`">7@!
M^'@E`*\H+0`#S[@``WBZ`R_()=^X`#@"&1@F`!!P/`,-P"T`#G`^`&(8)``%
M*#P`!2@^`P8P+0!N&"8`!<;Z`&88+0`%,7@`V#`E`&88+0`"Q[@``C"Z`P;`
M)0,X$"8`&7@\W[D`0``/>#X#+<@M`$40)``#&#P``Q@^`RYP+0!/$"8``\[Z
M`$X0+0`#<7@!V7`E`$X0+0`%S[@`!7"Z`R[()0,9*"8`&#`\W[@`2``&,#X#
M#<`M`*,H)``"$#P``A`^`P]X+0"F*"8``L;Z`*\H+0`">7@!^'@E`*\H+0`#
MQ[@``WBZ`P_`)0,X&"8`&7`\W[D`4``.<#X#+<@M`&(8)``%*#P`!2@^`R8P
M+0!N&"8`!<[Z`&88+0`%,7@`V3`E`&88+0`"S[@``C"Z`R8P)0,&$"8`&'@\
MW[@`6``/>#X##<`M`$40)``#&#P``Q@^`PYP+0!/$"8``\;Z`$X0+0`#<7@!
MV'`E`$X0+0`%=[@`!2BZ`<5P)=^E`&``!H`\`,XP)@"M*"T`$(`^`,,P)``"
M$#P``A`^`*]X+0#0,"8`SS`M``(I>``"?OH`KR@E``//N``#&+H#(\@E`,4P
M+=^C`&@`#L`\``8P/`'9<"8`!C`^`&T8+0`8P#X!PG`D`'"`+0`&+OH!V'`F
M``89>`!E&"4!T'`M`<-P+0`"'[@``A"Z`&(0)=^C`'``&7@\``YP/`,BR"8`
M#G`^`&T8+0`/>#X#)L@D`'C`+0`.+OH#+\@F``X9>`!E&"4#.,@M`R/(+0`&
M*+H`!A^X`&4H)0!%,"8``H`\WZ(`>``9R#P`&<@^`$T0+0`0@#X`SC`D`$]X
M+0`9'OH`T#`F`!D1>`!#$"4`SS`M``X?N``.<+H`;A@E`,(P+=^B`(``!<`\
M``8P/`"C*"8`!C`^`$T0+0`8P#X`N2@D`%"`+0`&=OH`N"@F``81>`!.$"4`
ML"@M`*(H+0`9%[@`&<BZ`%D0)=^N`(@``W@\`&(8)@'-<"T`#W@^`&88)``%
M*#P`!2@^`=C`+0!O&"8`>!@M``5Q>``%QOH!V'`E`&X8+0`&=[@`!C"Z`<8P
M)=^X`)```H`\`$80)@,-P"T`$(`^`$40)``#&#P``Q@^`P]X+0!0$"8``\;Z
M`$\0+0`#>7@!^'@E`$\0+0`%?[@`!2BZ`>4H)=^O`)@``A`\``(0/@'M>"T!
M\(`M``9P/``"?OH`Q3`F``+!>``.<#X`PS`D`P_`)0#.,"8``W^X`!C`/``#
M&+H!XQ@E`-`P+=^O`*``&,`^`-@P+0`%D#P`HR@F`!*0/@`&R#P`HB@D`>UH
M+0`9R#X`LB@F`:YH+0"M:"T`&7;Z`!DI>`"N*"4`!2@\``4H/@&E:"T``B^X
M``(0N@"B$"4`8L`F`P;`)CP%;MG?I@"H-*7KH0`-F#P`$Y@^`,4P+0#2D"T`
M$W;ZWZ\`L``3,7@`SC`E`!F/N``8P#P`&<BZ``,8/`(YB"4!Y7@M``,8/@`8
MP#X`!C`\`Q+`+0`&,#X!XW@M`%$8)@,&P"T`;6@F`!B0/``-:#P`$I`^``UH
M/@`2'OH![7@M`!)I>`&C:"4`#6@\WZ8`N``-:#X![7@M`!//N``"$#P`$YBZ
M`S/()0`/@#P`Q3`M``(0/@`0@#X`PC`M`CD0)@!8P"8`$'%X`!`6^@'"<"4`
M&,`\`!C`/@`.<#P`V#`M``YP/@#.,"T`$L>X`!*0N@,2P"4`!I@\`!.8/@,X
M$";?K0#``$]X)@`3&7@`$Q;Z`!&(/`&E:"T`$8@^`&(8)0`/>#P!L6@M``]X
M/@`#&#P!KV@M``,8/@&C:"T`$(^X`!"`N@(PB"4`#9`\`!*0/@,1$";?K@#(
M`!(>^@!&,"8`&<@\`!(1>`'%<"T`&<@^`$,0)0`&,#P!V7`M``8P/@`"$#P!
MQG`M``(0/@'"<"T`$\^X`!.8N@,SR"4`#H`\`!"`/@(Y$";?HP#0`$UH)@`0
M,7@`$!;Z`!C`/`!E&"T`&,`^`,(P)0`-:#P`>!@M``UH/@`&,#P`;1@M``8P
M/@!F&"T`$G^X`!*0N@'R>"4``\`\`!C`/@,O,";?H@#8`,YP)@`8:7@`&#;Z
M`!&(/`!%$"T`$8@^`:9H)0`.<#P`41`M``YP/@`0C[@`#6@\`!"`N@(PB"4`
M3A`M``UH/M^F`.``31`M`?%H)@&C&"8`&<@\``*0/`#%,"T`&<@^``,8/``2
MD#X`V3`M``,8/@##,"T`$G%X`!(>^@'#<"4`&,^X`!C`N@,XR"4`#G`\`CD8
M)M^M`.@`#G`^`,XP+0!B$"8`#W@\``:`/`&E:"T`#W@^``(0/``0@#X!KV@M
M``(0/@&B:"T`$!EX`!`6^@!B&"4``Q@\``,8/@&C:"T`$G^X`!*0N@'R>"4`
M#<`\`!C`/@,O$";?K@#P`!@>^@!&,"8`$8@\`!@1>`'%<"T`$8@^`$,0)0`&
M,#P!T7`M``8P/@`"$#P!QG`M``(0/@'"<"T`$(^X`!"`N@(PB"4`#I`\`!*0
M/@'Q$";?HP#X`$UH)@`2,7@`$A;Z`!G(/`!E&"T`&<@^`,(P)0`-:#P`>1@M
M``UH/@`&,#P`;1@M``8P/@!F&"T`&(>X`!C`N@(8@"4``Y@\`!.8/@(P,";?
MH@$``,YP)@`3:7@`$S;Z``]X/`!%$"T`#W@^`:9H)0`.<#P`3Q`M``YP/@`2
M?[@`#6@\`!*0N@'R>"4`3A`M``UH/@!-$"W?I@$(`@]H)@&C&"8`$8@\``+(
M/`#%,"T`$8@^``,8/``9R#X`T3`M``,8/@##,"T`&<%X`!D>^@,#P"4`$X^X
M`!.8N@(SB"4`&,`\`?$8)M^M`1``&,`^`-@P+0!B$"8`$(`\``:0/`&E:"T`
M$(`^``(0/``2D#X!L&@M``(0/@&B:"T`$AEX`!(6^@!B&"4``Q@\``,8/@&C
M:"T`&8>X`!G(N@(9@"4`#9@\`!.8/@(P$";?N`$8`$8P)@`3<7@`$Q;Z``]X
M/`,%P"T`#W@^`<)P)0`&,#P##\`M``8P/@`.<#P#!L`M``YP/@,.P"T`$G^X
M`!*0N@'R>"4`&,@\`!G(/@(/$";?HP$@`$UH)@`9,7@`&1;Z`!&(/`!E&"T`
M$8@^`,(P)0`-:#P`<1@M``UH/@`&,#P`;1@M``8P/@!F&"T`$X^X`!.8N@(S
MB"4``Y`\`!*0/@'Q$";?K@$H`!(V^@!8P"8`$(`\`!(1>`'%<"T`$(`^`$80
M)0`8P#P!T'`M`!C`/@`9A[@``A`\`!G(N@(9@"4!V'`M``(0/@'"<"W?I@$P
M`C`0)@!#&"8`#W@\``[`/`#%,"T`#W@^``,8/``8P#X`SS`M``,8/@##,"T`
M&!%X`!@>^@!#$"4`$G^X``(0/``2D+H!\G@E``(0/@(/&"8`PC`MWZ(!.``&
MR#P`;G`F`!&(/``9R#X`11`M`!&(/@`.<#P`&6[Z`%$0+0`.<#X`&1EX`&T8
M)0!.$"T`0Q`M``)P/``8C[C?H@%``!C`N@(XB"4`12@M`?$0)@!&,"8`$(`\
M``YP/@`0@#X`!C`\``X>^@"P*"T`!C`^``X1>`!#$"4`IB@M`!D?N``9R+H`
M>1@E`*(H+3P"(\;?I@%(``/(/#1"[S<``A"X`!G(/@(C:"4`#W@\`,(P+0`1
MP#P!KF@D`CF()``%*#P`#W@^``4H/@#/>"T!L6@E`:]H+0`%,7@`!7[Z`,\P
M)0&F:"T`#C>X``YPN@#.<"4`;A@E`=DP)`!E&"0`9A@EWZ8!4``8P#X`PC`M
M``UH/``-:#X`V,`M`'@8+0`-,7@`#<;Z`-@P)0!F&"T`!3>X``4HN@#%*"4`
M!<`\`!C`/@'%,"4`#G@\`,TP)`'8<"0`SC`EWZX!6``#&#P!PG`M``,8/@'9
MR"T`V3`M``-Q>``#SOH!V7`E``W/N``-:+H#+<@E`+DH)0,X:"0`HR@D`*TH
M)=^M`6``SC`M`:)H+0`/>#X`!C`\``8P/@&O>"T`KR@M``9I>``&?OH!KV@E
M`*TH+0`#;[@``QBZ`:,8)0`#>#P`#W@^`R-H)0`9<#P!IF@D`R_()`&Y:"7?
MN0%H``4H/`,BR"T`!2@^`SC`+0&X:"T`!<[Z``7!>`,9P"4`!L^X``8PN@,F
MR"4`>1@E`R\P)`!E&"0`9A@EWZ8!<`&X:"T`PC`M``YP/@`-:#P`#6@^`,YP
M+0!N&"T`#3%X``UV^@#.,"4`9A@M``4WN``%*+H`Q2@E``5P/``.<#X#)3`E
M`!G`/`#-,"0#+L@D`-DP)=^Y`7@``Q@\`R+(+0`#&#X#+W@M`,\P+0`#SOH`
M`WEX`?EX)0`-S[@`#6BZ`RW()0"Y*"4#+F@D`*,H)`"M*"7?K0&``,\P+0&B
M:"T`&,`^``8P/``&,#X!N,`M`+@H+0`&:7@`!L;Z`;AH)0"M*"T``V^X``,8
MN@&C&"4``\`\`!C`/@,C:"4`&7@\`:9H)`,XR"0!N6@EW[D!B``%*#P#(L@M
M``4H/@,N<"T!KF@M``7.^@`%<7@!V7`E``;/N``&,+H#)L@E`'D8)0,X,"0`
M91@D`&88)=^F`9`!KF@M`,(P+0`/>#X`#6@\``UH/@#/>"T`;Q@M``TQ>``-
M?OH`SS`E`&88+0`%-[@`!2BZ`,4H)0`%>#P`#W@^`R4P)0`9<#P`S3`D`R_(
M)`#9,"7?N0&8``,8/`,BR"T``Q@^`SC`+0#8,"T``\[Z``/!>`,9P"4`#<^X
M``UHN@,MR"4`N2@E`R]H)`"C*"0`K2@EWZT!H`#8,"T!HF@M``YP/@`&,#P`
M!C`^`:YP+0"N*"T`!FEX``9V^@&N:"4`K2@M``-ON``#&+H!HQ@E``-P/``.
M<#X#(V@E`!G`/`&F:"0#+L@D`;EH)=^Y`:@`!2@\`R+(+0`%*#X#+W@M`:]H
M+0`%SOH`!7EX`?EX)0`&S[@`!C"Z`R;()0!Y&"4#+C`D`&48)`!F&"7?I@&P
M`:]H+0#","T`&,`^``UH/``-:#X`V,`M`'@8+0`-,7@`#<;Z`-@P)0!F&"T`
M!3>X``4HN@#%*"4`!<`\`!C`/@,E,"4`&7@\`,TP)`,XR"0`V3`EW[D!N``#
M&#P#(L@M``,8/@,N<"T`SC`M``/.^@`#<7@!V7`E``W/N``-:+H#+<@E`+DH
M)0,X:"0`HR@D`*TH)=^M`<``SC`M`:)H+0`/>#X`!C`\``8P/@&O>"T`KR@M
M``9I>``&?OH!KV@E`*TH+0`#;[@``QBZ`:,8)0`#>#P`#W@^`R-H)0`9<#P!
MIF@D`R_()`&Y:"7?N0'(``4H/`,BR"T`!2@^`SC`+0&X:"T`!<[Z``7!>`,9
MP"4`!L^X``8PN@,FR"4`>1@E`R\P)`!E&"0`9A@EWZ8!T`&X:"T`PC`M``YP
M/@`-:#P`#6@^`,YP+0!N&"T`#3%X``UV^@#.,"4`9A@M``4WN``%*+H`Q3`E
M``:`/``0@#X#)B@E`S!P)`"M*"0`KB@EWZX!V``#&#P!PG`M``,8/@'/>"T`
MKW@M``-V^@`#*7@`KB@E``4H/``%*#X!Y7@M``TON``-:+H`K6@E`,TP)0&P
M*"0`&<`\`,,P)``/R#P`&<@^`,4P)=^E`>``&9[Z`!EQ>``8P#X`HA`M`=-P
M)0!8$"T`#G`\`,(0+0`.<#X`3I@M/`)E,0`#Q[C?I@'H``,8NF1"8.L``A!X
M`P,8)0`3D#P`$I`^`:,H)@#","T`T(`M``V(/`"O*"8`$F[Z`!(Q>`#-,"4`
M!2@\``4H/@`&,#P`L"@M``8P/@"F*"T`&7^XWZ8!\``9R+H!^7@E``6`/``0
M@#X`;W`F`,(P+0`1B#X`T8@M`!!N^@'3<"8`$#%X`,TP)0`.<#P`#G`^``8P
M/`'1<"T`!C`^W[@!^`'&<"T`$L^X``,8/``2D+H#,L@E``Z8/`,"P"T``Q@^
M`!.8/@,#P"T!^1@F`&4H)@`3:7@`$Q[Z`:-H)0`%*#P`!2@^``UH/`,%*"T`
M#6@^`*TH+0`0C[@`$("Z`C"()0`%D#P`$I`^`S$8)M^F`@``$F[Z`&YP)@`/
M>#P`$AEX`,(P+0`/>#X`;1@E``YP/`#/,"T`#G`^`!-_N``#&#P`$YBZ`?-X
M)0#.,"T``Q@^`,,P+=^M`@@"+Q@F`&4H)@`9R#P`!H`\`:)H+0`9R#X`!2@\
M`!"`/@&Y:"T`!2@^`:5H+0`0&7@`$"[Z`&48)0`#&#P``Q@^`:-H+0`2Q[@`
M$I"Z`Q+`)0`-R#S?I0(0`!G(/@'X&"8`$8@\`*(H+0`1B#X`9C`F`!EQ>``9
M'OH`L2@M`<-P)0`0C[@`!C`\`!"`N@(PB"4`!C`^``YP/`"F*"T`#G`^`Q$P
M)M^C`A@`KB@M`,UH)@`/>#P`!9`\`&(8+0`/>#X`#6@\`!*0/@!O&"T`#6@^
M`&T8+0`2,7@`$F[Z`,TP)0`9?[@`!C`\`!G(N@'Y>"4`!C`^`&88+=^N`B`"
M+S`F`,4H)@`8P#P``X`\`<)P+0`8P#X`!2@\`!"`/@'8<"T`!2@^`<5P+0`0
M:7@`$"[Z`:5H)0`2Q[@`$I"Z`Q+`)0`-:#P!^"@F``UH/M^F`B@!S7`M`*,8
M)@`1B#P`#L@\`,(P+0`1B#X``Q@\`!G(/@#1,"T``Q@^`,,P+0`9*7@`&1[Z
M`*,H)0`%*#P`!2@^`,4P+0`0E[@`$("Z`E"0)0`&F#P`$Y@^`Q(8)M^M`C``
M$R[Z`&YP)@`/>#P`$QEX`:)H+0`/>#X`91@E``YP/`&O:"T`#G`^``,8/`&N
M:"T``Q@^`:-H+0`9A[@`&<BZ`AF`)0`-B#S?I0(X`!&(/@)0&"8`&,`\`*(H
M+0`8P#X`9C`F`!%Y>``1'OH`N"@M`>-X)0`3Q[@`!C`\`!.8N@,3P"4`!C`^
M``]X/`"F*"T`#W@^`A@P)M^C`D``KR@M`,UH)@`2D#P`!<@\`&(8+0`2D#X`
M#6@\`!G(/@!R&"T`#6@^`&T8+0`9,7@`&6[Z`,TP)0`1E[@`!C`\`!&(N@)1
MD"4`!C`^`&88+=^O`D@#$C`F`,4H)@`0@#P``Y@\`>)X+0`0@#X`!2@\`!.8
M/@'P>"T`!2@^`>5X+0`3<7@`$R[Z`<5P)0`9A[@`&<BZ`AF`)0`.<#P"4"@F
M``YP/M^F`E`![G@M`*,8)@`8P#P`#X@\`,(P+0`8P#X``Q@\`!&(/@#8,"T`
M`Q@^`,,P+0`1:7@`$1[Z`:-H)0`-:#P`#6@^`,TP+0`3Q[@`$YBZ`Q/`)0`&
MR#P`&<@^`A@8)M^N`E@`;W@F`!DI>``9'OH`$I`\`<)P+0`2D#X`HR@E``]X
M/`'2<"T`#W@^``4H/`'/<"T`!2@^`<5P+0`1E[@`$8BZ`E&0)0`.F#P`$Y@^
M`Q(8)M^M`F``9C`F`!-Y>``3'OH`$(`\`:)H+0`0@#X!XW@E``8P/`&P:"T`
M!C`^``]X/`&F:"T`#W@^`:]H+0`9A[@`&<BZ`AF`)0`-B#P`$8@^`E`8)M^E
M`F@`$3;Z`&YP)@`8P#P`$1EX`*(H+0`8P#X`9A@E``YP/`"X*"T`#G`^``,8
M/`"N*"T``Q@^`*,H+0`3Q[@`$YBZ`Q/`)0`%R#P`&<@^`A@8)M^O`G``&3;Z
M`&UH)@`2D#P`&1EX`>)X+0!F&"4`$I`^``UH/``-:#X`$3>X`?)X+0`#&#P`
M$8BZ`-$P)0'M>"T``Q@^`P9P)@'C>"W?HP)X`<4H)@`0@#P`#V@\`&(8+0`0
M@#X`!2@\``UH/@`%*#X`<!@M``UV^@!E&"T`#2EX`*XH)0!E&"T`&7>XWZ4"
M@``9R+H!V7`E`*(0+0#.*"8`KW@F``,8/``8P#P``Q@^`$P0+0`8P#X`#W@\
M``,I>``#9OH`6!`M``]X/@!/$"T`K"@E`$40+0`"$#P``A`^_((```!I&"T`
M#1>X``UHN@!-$"4``Q@\``,8/@!'."T!R'`M`,LP+?R#``@`!S@\WZ,"B``.
M<#P`!C`\W4(````'.#X`#G`^``8P/OR'`!#\C@`8$&(`!/R&`"#?F8$8`R#X
M"0````#?OP*XW[P"L-^S`JC?L@*@W[$"F-^P`I`#X``(9[T"P&>]__#_O```
M/!P``@.9X"UGG,G<WYF"F/^_``@#(/@))`0`@#P$9T5DA",!_$0``"0$=^<`
M!"1X9(2KB?Q$``@\!$Q=9(1N?P`$('C\1``0/`00,F2$5';\1``8/`0,/62$
M+A\`!"$X_$0`(/Q``"C\0``PK$``>-^_``C?O````^``"&>]`!!GO?_`_[P`
M,/^Q``C_L```_[\`./^U`"C_M``@_[,`&/^R`!#<@P`H``80^`!#$"T``A`\
M/!P``@`"$#X#F>`M`$,8*V><R50`@(`E$&``!`#`B"7<@P`P9&,``?R#`##>
M`P`P_@(`*(X$`'@`$1=Z`&(0+?X"`#`0@``?9A(`."0"`$``1!`C`%$8*A!@
M``("(#`E`$`P)0)$("T`A1`K$$```P#`H"4`E!`M`*(`,P"D$"L00``"`*:8
M+0"3`#/?F8$P`R#X"0````".`@!X)`,`0`!4$"$40P`;K@(`>-^9@%@"`"`E
M9SD\<`,@^`D"-(@C`F`H)=^3@%AF%0!X9G,\<"HB`$#?F8$P$$``&0)%&"L0
M8``$`+(0*P)1$"T`H@`S`+(0*Q!```0"(#`E`+$0+0)"`#,"(#`E`R#X"0)`
M("6N$0!XW[\`.-^\`##?M0`HW[0`(-^S`!C?L@`0W[$`"-^P```#X``(9[T`
M0````#008``$`+(0*P"U$"L40/_[`+(0*Q!```1DM`!``E00*Q1`__8`````
M)`8`0`)`("4#(/@))C'_P`)@R"4#(/@)`@`@)1``_]("@"@E9[W_P/^\`##_
MM0`H_[,`&/^Q``C_L```_[\`./^T`"#_L@`0W+(`*#P<``(`$A#Z`YG@+3!"
M`#]GG,>4`$`8)62U`#@D0@`!`J,8+=^3@%@`@(@E)`3_@-RT`#"@9```*$,`
M.=^9@K``H(`E`J(@+11@`&-F<SQP)`8`0`#",",#(/@)```H)0)@R"4#(/@)
M`@`@)=^9@K`D!@`X```H)0*@("4#(/@)```````4%CJB`@!P`!04.J("`'$`
M%!(ZH@(`<@`2%CJB`@!T`!(4.J("`'4"`"`E`!(2.@)@R"6B%`!SH@(`=@,@
M^`FB$@!WW@(``-^9@6@``A8ZHB(``-X"```"`"`E``(4.J(B``'>`@````(2
M.J(B``+>`@``HB(``]X"``@``A8ZHB(`!-X"``@``A0ZHB(`!=X"``@``A(Z
MHB(`!MX"``BB(@`'W@(`$``"%CJB(@`(W@(`$``"%#JB(@`)W@(`$``"$CJB
M(@`*W@(`$*(B``O>`@`8``(6.J(B``S>`@`8``(4.J(B``W>`@`8``(2.J(B
M``[>`@`8HB(`#]X"`"```A8ZHB(`$-X"`"```A0ZHB(`$=X"`"```A(ZHB(`
M$MX"`"`#(/@)HB(`$]^_`#C?O``PW[4`*-^T`"#?LP`8W[(`$-^Q``C?L```
M`^``"&>]`$`D!@`X`,(P(Q``_Z8``"@E`````&>]_^#_O``0/!P``@.9X"UG
MG,6`WX.`."0"___<>9_@_[\`&/^Q``@3(@`(_[```"01__]D<)_@`R#X"680
M__C>&0``%S'__`````#?OP`8W[P`$-^Q``C?L````^``"&>]`"``````````
M``````#?F8`0`^!X)0,@^`ED&`!HWYF`$`/@>"4#(/@)9!@`9=^9@!`#X'@E
M`R#X"608`&3?F8`0`^!X)0,@^`ED&`!CWYF`$`/@>"4#(/@)9!@`8M^9@!`#
MX'@E`R#X"608`&'?F8`0`^!X)0,@^`ED&`!@WYF`$`/@>"4#(/@)9!@`7]^9
M@!`#X'@E`R#X"608`%W?F8`0`^!X)0,@^`ED&`!<WYF`$`/@>"4#(/@)9!@`
M6]^9@!`#X'@E`R#X"608`%K?F8`0`^!X)0,@^`ED&`!9WYF`$`/@>"4#(/@)
M9!@`6-^9@!`#X'@E`R#X"608`%??F8`0`^!X)0,@^`ED&`!6WYF`$`/@>"4#
M(/@)9!@`5=^9@!`#X'@E`R#X"608`%3?F8`0`^!X)0,@^`ED&`!3WYF`$`/@
M>"4#(/@)9!@`4M^9@!`#X'@E`R#X"608`%'?F8`0`^!X)0,@^`ED&`!0WYF`
M$`/@>"4#(/@)9!@`3M^9@!`#X'@E`R#X"608`$W?F8`0`^!X)0,@^`ED&`!,
MWYF`$`/@>"4#(/@)9!@`2M^9@!`#X'@E`R#X"608`$G?F8`0`^!X)0,@^`ED
M&`!(WYF`$`/@>"4#(/@)9!@`1]^9@!`#X'@E`R#X"608`$;?F8`0`^!X)0,@
M^`ED&`!%WYF`$`/@>"4#(/@)9!@`1-^9@!`#X'@E`R#X"608`$+?F8`0`^!X
M)0,@^`ED&`!!WYF`$`/@>"4#(/@)9!@`/]^9@!`#X'@E`R#X"608`#S?F8`0
M`^!X)0,@^`ED&``[WYF`$`/@>"4#(/@)9!@`.M^9@!`#X'@E`R#X"608`#G?
MF8`0`^!X)0,@^`ED&``WWYF`$`/@>"4#(/@)9!@`-M^9@!`#X'@E`R#X"608
M`#7?F8`0`^!X)0,@^`ED&``TWYF`$`/@>"4#(/@)9!@`,=^9@!`#X'@E`R#X
M"608`##?F8`0`^!X)0,@^`ED&``OWYF`$`/@>"4#(/@)9!@`+M^9@!`#X'@E
M`R#X"608`"S?F8`0`^!X)0,@^`ED&``KWYF`$`/@>"4#(/@)9!@`*M^9@!`#
MX'@E`R#X"608`"G?F8`0`^!X)0,@^`ED&``HWYF`$`/@>"4#(/@)9!@`)]^9
M@!`#X'@E`R#X"608`";?F8`0`^!X)0,@^`ED&``EWYF`$`/@>"4#(/@)9!@`
M)`````````````````````!GO?_@_[P`$/^_`!@`````!!$``0`````#@!`E
M/!P``B><P6@#G^`MWYF`8`,@^`D`````W[P`$-^_`!@#X``(9[T`(```````
M`````````%!!4E]435!$25(```````!435!$25(``%1%35!$25(`5$5-4```
M``!435```````"X`````````+BX````````E<R\E<P```$1Y;F%,;V%D97(Z
M.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z.D)/3U0`````
M97AE```````O<')O8R\E:2\E<P``````4$%27U1%35```````````%!!4E]0
M4D]'3D%-10`````Z`````````"\`````````)7,E<R5S``!015),-4Q)0@``
M````````4$523$Q)0@!015),-4]05```````````4$523$E/``!005)?24Y)
M5$E!3$E:140`4$%27U-005=.140``````%!!4E]#3$5!3@````````!005)?
M1$5"54<`````````4$%27T-!0TA%`````````%!!4E]'3$]"04Q?1$5"54<`
M`````````%!!4E]'3$]"04Q?5$U01$E2`````````%!!4E]'3$]"04Q?5$5-
M4`!005)?1TQ/0D%,7T-,14%.``````````!005)?0TQ%04X]````````,0``
M``````!,1%],24)205)97U!!5$@`4UE35$5-```O=&UP`````%5315(`````
M55-%4DY!344``````````"4P,G@`````<&%R+0`````E<R5S)7,E<P``````
M````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&9A
M:6QE9"`H97)R;F\])6DI"@```````"5S.B!P<FEV871E('-U8F1I<F5C=&]R
M>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO
M=7(@;W!E<F%T:6]N*0H```````!0051(`````'!A<FP`````+G!A<@`````E
M<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U
M)7,``````````!@`````````<&5R;``````P`````````%!!4CHZ4&%C:V5R
M.CI615)324].`````#$N,#4R````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD``````````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE
M('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE
M````````+2T```````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P
M("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H
M96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E
M;7`L("1P<F]G;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![
M(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PIO=71S*'%Q6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I
M;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N
M;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D
M<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W
M($9I;&4Z.E1E;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&
M:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N
M8VUD)RP*54Y,24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I
M;&5N86UE.PIP<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@
M+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D
M<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD
M>"`K(#%@"F1O;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H
M;6]D(#`W,#`L("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D
M978O;G5L;"`R/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE
M9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL
M96YA;65=*3L*?0I]('T*0D5'24X@>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D
M<75I970@/2`A)$5.5GM005)?1$5"54=].PIM>2`E0V]N9FEG(#T@*`IP871H
M7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN
M?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PI?<V5T
M7W!A<E]T96UP*"D["FUY("@D<W1A<G1?<&]S+"`D9&%T85]P;W,I.PI["FQO
M8V%L("1324=[7U]705).7U]](#T@<W5B('M].PIO<&5N(%]&2"P@)SPZ<F%W
M)RP@)'!R;V=N86UE(&]R(&QA<W0["FUY("1B=68["FUY("1S:7IE(#T@+7,@
M)'!R;V=N86UE.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R-#L*;7D@)&UA
M9VEC7W!O<SL*:68@*"1S:7IE(#P]("1C:'5N:U]S:7IE*2!["B1M86=I8U]P
M;W,@/2`P.PI](&5L<VEF("@H;7D@)&T@/2`D<VEZ92`E("1C:'5N:U]S:7IE
M*2`^(#`I('L*)&UA9VEC7W!O<R`]("1S:7IE("T@)&T["GT@96QS92!["B1M
M86=I8U]P;W,@/2`D<VEZ92`M("1C:'5N:U]S:7IE.PI]"G=H:6QE("@D;6%G
M:6-?<&]S(#X](#`I('L*<V5E:R!?1D@L("1M86=I8U]P;W,L(#`["G)E860@
M7T9(+"`D8G5F+"`D8VAU;FM?<VEZ92`K(&QE;F=T:"@D4$%27TU!1TE#*3L*
M:68@*"AM>2`D:2`](')I;F1E>"@D8G5F+"`D4$%27TU!1TE#*2D@/CT@,"D@
M>PHD;6%G:6-?<&]S("L]("1I.PIL87-T.PI]"B1M86=I8U]P;W,@+3T@)&-H
M=6YK7W-I>F4["GT*;&%S="!I9B`D;6%G:6-?<&]S(#P@,#L*<V5E:R!?1D@L
M("1M86=I8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?
M1D@L("1M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D
M871A7W!O<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&
M2"P@)&)U9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@
M=&AE(&9I<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@
M1DE,12`B)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@
M/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A
M<V5N86UE+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI
M?"D["G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K
M*").(BP@)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<
M+B@_.G!M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A
M<R@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#
M86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L
M;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L
M;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%
M35!]("D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X
M="(L("1B=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*
M?0IE;'-E('L*)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*)$UO9'5L94-A
M8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*
M;F%M92`]/B`D9G5L;&YA;64L"GT["GT*<F5A9"!?1D@L("1B=68L(#0["GT*
M;&]C86P@0$E.0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\[
M"G)E='5R;B!I9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@
M/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D:6YF;R\D;6]D=6QE(CL*:68@*"1%
M3E9[4$%27T-,14%.?2!A;F0@9&5F:6YE9"@F24\Z.D9I;&4Z.FYE=RDI('L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=U]T;7!F:6QE(&]R(&1I92`B0V%N)W0@
M8W)E871E('1E;7`@9FEL93H@)"$B.PHD9F@M/F)I;FUO9&4H*3L*)&9H+3YP
M<FEN="@D:6YF;RT^>V)U9GTI.PHD9F@M/G-E96LH,"P@,"D["G)E='5R;B`D
M9F@["GT*96QS92!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D:6YF;RT^
M>V-R8WTN<&TB+"`D:6YF;RT^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)&9I;&5N86UE(&]R(&1I92!Q<5M#86XG="!R96%D("(D9FEL96YA;64B
M.B`D(5T["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A:6QE
M9#H@8V%N)W0@9FEN9"!M;V1U;&4@)&UO9'5L92$B.PI]+"!`24Y#*3L*<F5Q
M=6ER92!84TQO861E<CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E($-A
M<G`Z.DAE879Y.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PIR97%U:7)E($E/.CI&:6QE.PIW:&EL
M92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q=6ER95]L:7-T*5LP
M72D@>PIU;FQE<W,@*"1)3D-[)&9I;&5N86UE?2!O<B`D9FEL96YA;64@/7X@
M+T)31%!!3B\I('L*:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["G)E
M<75I<F4@)&9I;&5N86UE.PI]"F5L<V4@>PID;R`D9FEL96YA;64@=6YL97-S
M("1F:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*?0I]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["GT*;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@
M-#L@("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R
M9W,["FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*
M9&5L971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%
M(&UA>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S
M("1%3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP
M72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M
M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U
M;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII
M9B`H0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`
M05)'5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L
M<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*
M=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S
M5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D
M7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@
M)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L
M("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF
M("@D,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@
M97$@)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G
M*2!["B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L
M;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@
M(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@
M/2`D,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD
M>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*
M<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL
M97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6
M.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF
M("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E
M.CI::7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T
M*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R
M(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*
M;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^
M8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O
M;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK
M*3H@*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY
M("1P:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@
M9FEL92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0[
M"F1I92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U
M="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ
M3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ
M3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL
M92`B)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P
M.PIM>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?
M1D@L("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U
M;F1E9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%4
M24U](&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP
M+3YA<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R
M="!K97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*
M)'9A;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I
M8R`](")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`]
M(")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M
M86=I8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I
M("T@;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD[
M"FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V
M>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO
M9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L*
M*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG
M>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI
M8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC
M.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L
M7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D
M0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X
M="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I
M;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2![
M"B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A
M8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H
M+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*
M?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H
M;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@
M/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F
M:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD
M;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN
M7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%
M("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I
M*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@
M)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N
M(&UY("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D
M9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE
M(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N
M=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*
M)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@
M.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#
M4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N
M=&5N="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B
M72D["GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`[
M"B1C86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@
M*"$D8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F
M:"P@(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D
M9F@["B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N
M86UE("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C
M:&5?;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*
M)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&
M:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI
M=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N
M*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z
M("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@
M)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL
M94AA;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/
M2R@I("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P
M<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P
M,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M72D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<5M3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92)=*3L*?2!E;'-E('L*;W5T<RAQ<5M%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(ETI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER
M92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!005(Z.D1I<W0[
M"G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ
M1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T<FEB=71E<SL*979A
M;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E(%=I;C,R('T["F5V
M86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L('L@<F5Q=6ER92!!
M<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I<F4@4&5R;$E/.R!R
M97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R97%U:7)E('5T9C@@
M?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I;F5D("1%3E9[4$%2
M7U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*)'!A<E]T
M96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P871H("@**&UA<"`D
M14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!4
M35`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*;F5X="!U;FQE<W,@
M9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW("1P871H.PIM>2`D
M=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I9"D@/2!G971P=W5I
M9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN960H)E=I;C,R.CI,
M;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*
M?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N86UE(#T@)'!W=6ED
M.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).04U%?2!\?"`D14Y6
M>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*
M;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A
M8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF
M("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O
M9VYA;64I*5LY72D@>PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE
M(&]R(&1I92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["G-E96L@
M)&9H+"`M,3@L(#(["FUY("1B=68["G)E860@)&9H+"`D8G5F+"`V.PII9B`H
M)&)U9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("TU."P@,CL*<F5A9"`D
M9F@L("1B=68L(#0Q.PHD8G5F(#U^(',O7#`O+V<["B1S=&UP9&ER("X]("(D
M0V]N9FEG>U]D96QI;7UC86-H92TD8G5F(CL*?0IE;'-E('L*;7D@)&1I9V5S
M="`](&5V86P*>PIR97%U:7)E($1I9V5S=#HZ4TA!.PIM>2`D8W1X(#T@1&EG
M97-T.CI32$$M/FYE=R@Q*3L*;W!E;B!M>2`D9F@L("(\.G)A=R(L("1P<F]G
M;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R;V=N86UE(CH@)"%=.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["B1C='@M/FAE>&1I9V5S
M=#L*?2!\?"`D;71I;64["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC
M86-H92TD9&EG97-T(CL*?0IC;&]S92@D9F@I.PI]"F5L<V4@>PHD14Y6>U!!
M4E]#3$5!3GT@/2`Q.PHD<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]=&5M
M<"TD)"(["GT*)$5.5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FQA<W0["GT*)'!A<E]T96UP(#T@)#$@:68@)$5.5GM0
M05)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+SL*?0IS=6(@
M7W-A=F5?87,@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^.G)A=R<L("1T96UP;F%M92!O<B!D:64@<7%;0V%N
M)W0@=W)I=&4@(B1T96UP;F%M92(Z("0A73L*<')I;G0@)&9H("1C;VYT96YT
M<SL*8VQO<V4@)&9H.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN
M960@)&UO9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL
M:6YK*"1T96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E
M=%]P<F]G;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A
M;F0@)$5.5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@
M/2`D,3L*?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@
M86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*
M)'!R;V=N86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/
M1TY!345](&]R(&EN9&5X*"1P<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`^
M/2`P*2!["FEF("AO<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T
M=7)N(&EF("US("1F:#L*?0II9B`H+7,@(B1P<F]G;F%M921#;VYF:6=[7V5X
M97TB*2!["B1P<F]G;F%M92`N/2`D0V]N9FEG>U]E>&5].PIR971U<FX["GT*
M?0IF;W)E86-H(&UY("1D:7(@*'-P;&ET("]<421#;VYF:6=[<&%T:%]S97!]
M7$4O+"`D14Y6>U!!5$A]*2!["FYE>'0@:68@97AI<W1S("1%3E9[4$%27U1%
M35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PHD9&ER(#U^(',O7%$D
M0V]N9FEG>U]D96QI;7U<120O+SL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF
M:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[7V5X97TB*2P@;&%S="D*:68@
M+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5]
M(CL**"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE('Q\
M/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)$-O;F9I9WM?
M9&5L:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ
M9V5T8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'
M971#=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D
M*3L*)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D0V]N9FEG>U]D96QI;7U<
M12DO)'!W9"1#;VYF:6=[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]
M("1P<F]G;F%M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM0
M05)?24Y)5$E!3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD
M14Y6>U!!4E])3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@
M5$5-4"!#3$5!3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@
M)$5.5GLG4$%27R<N)%]].PI]"F9O<B`H<7<O(%1-4$1)4B!414U0($-,14%.
M($1%0E5'("\I('L*)$5.5GLG4$%27R<N)%]](#T@)$5.5GLG4$%27T=,3T)!
M3%\G+B1??2!I9B!E>&ES=',@)$5.5GLG4$%27T=,3T)!3%\G+B1??3L*?0IM
M>2`D<&%R7V-L96%N(#T@(E]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@(CL*:68@*"1%3E9[4$%27U1%35!]*2!["F1E;&5T92`D14Y6>U!!4E]#
M3$5!3GT["GT*96QS:68@*"%E>&ES=',@)$5.5GM005)?1TQ/0D%,7T-,14%.
M?2D@>PIM>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG
M=&@H(D-,14%.(BDI.PHD14Y6>U!!4E]#3$5!3GT@/2`D,2!I9B`D=F%L=64@
M/7X@+UY005)?0TQ%04X]*%Q3*RDO.PI]"GT*<W5B(&]U=',@>PIR971U<FX@
M:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F:"`B0%]<;B([
M"GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET7VEN8R!["G)E
M<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE9"P@;6%P("1#
M;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R:79L:6)E>'`@
M<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP('9E;F1O<FQI
M8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005(["G5N<VAI9G0@
M0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`<&%R7V%R9W,I
M.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D<')O
M9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y="G5N;&5S<R`M
M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI="@D,2D@:68@
M*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`(&EF("1`.PI]
M.PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI="@D,2D@:68@
M*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)#HZ
M7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@````````````!?
M7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````````<&5R;'AS
M:2YC````````````````````+VQI8B]L9"UM=7-L+6UI<',V-"US9BYS;RXQ
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````#__________P``````````________
M__\``````````````````%\@````````7S````````!?.````````%]`````
M````7T@``````````/____\```````````````````````!BV```````````
M````````````````````````````````@`````````````````!>T```````
M`!>P````````&0````````(``````````:!8```````!HX@```````&?^```
M````````````````'=@````````>V````````0``````````)A`````````X
MK````````";H````````+K@````````O`````````"Y$````````*$@`````
M``!6=````````%;\````````6+P````````L%````````#`4````````*M``
M```````JI````````:!`````````.[@```````!:T```````````````````
M``````````!>L````````%Z@````````7I````````!>@````````%YP````
M````7F````````!>4````````%Y`````````7C```````````````````%X@
M````````7A````````!>`````````%WP````````````````````````````
M`%W@````````7=````````!=P````````%VP``````````````````!=H```
M`````%V0````````78````````!=<`````````````````````````````!=
M8```````````````````75````````!=0```````````````````73``````
M``!=(````````%T0````````70````````!<\````````%S@````````7-``
M`````````````````%S`````````7+````````!<H```````````````````
M7)````````!<@````````%QP````````7&````````!<4````````%Q`````
M````7#````````!<(````````%P0````````7`````````!;\````````%O@
M````````6]````````!;P```````````````````6[````````!;H```````
M`%N0````````6X````````!;<````````%M@````````6U``````````````
M````````````````6T````````&CB$=#0SH@*$%L<&EN92`Q,"XS+C%?9VET
M,C`R,3`T,C0I(#$P+C,N,2`R,#(Q,#0R-````````!T`D````/____@`````
M`````````!`````=````'P``'S"0?P``____^```````````````4````!T`
M```?```@+)`!``#____X```````````````P````'0```!\``""4D`\``/__
M__@``````````````%`````=````'P``(4R0_P``____^``````````````!
M0````!T````?```C))`#``#____X``````````````$`````'0```!\``"/4
MD'\``/____@``````````````&`````=````'P``)A"0````____^```````
M````````$````!T````?```F:)`!``#____X```````````````@````'0``
M`!\``";HD`\``/____@`````````````(&`````=````'P``*#``````````
M`````````````````````!T````?```H2-#_``#____X`````````````!%0
M````'0```!\``"JD```````````````````````````````=````'P``*M"0
M`0``____^```````````````(````!T````?```L%)!_``#____X````````
M``````"`````'0```!\``"Y$D`$``/____@``````````````"`````=````
M'P``+KB0````____^```````````````$````!T````?```O`)`/``#____X
M```````````````P````'0```!\``#`4T/\``/____@`````````````@?``
M```=````'P``.*R0#P``____^```````````````,````!T````?```[N)`#
M``#____X```````````````@````'0```!\``!D`D`\``/____@`````````
M`````%`````=````'P``/'"0#P``____^``````````````"P````!T````?
M``!6=)````#____X```````````````0````'0```!\``%;\D#\``/____@`
M`````````````$`````=````'P``6+R0/P``____^```````````````0```
M`!T````?00````]G;G4``0````<$`P`N<VAS=')T86(`+DU)4%,N86)I9FQA
M9W,`+DU)4%,N;W!T:6]N<P`N9'EN86UI8P`N:&%S:``N9'EN<WEM`"YD>6YS
M='(`+G)E;"YD>6X`+FEN:70`+G1E>'0`+DU)4%,N<W1U8G,`+F9I;FD`+G)O
M9&%T80`N:6YT97)P`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S`"YD871A`"YR
M;&1?;6%P`"YG;W0`+G-D871A`"YB<W,`+F-O;6UE;G0`+G!D<@`N9VYU+F%T
M=')I8G5T97,`````````````````````````````````````````````````
M``````````````````````````````````````````MP```J``````````(`
M```````".`````````(X`````````!@````````````````````(````````
M`!@````:<```#0`````(```"`````````E`````````"4`````````$8````
M````````````````"``````````!````*`````8``````````@````````-H
M`````````V@````````"``````8```````````````@`````````$````#$`
M```%``````````(````````%:`````````5H`````````S`````%````````
M```````(``````````0````W````"P`````````"````````")@````````(
MF`````````G8````!@````(`````````"``````````8````/P````,`````
M`````@```````!)P````````$G`````````$D`````````````````````$`
M`````````````$<````)``````````(````````7`````````!<`````````
M`(`````%```````````````(`````````!````!0`````0`````````&````
M````%[`````````7L`````````!H````````````````````"```````````
M````5@````$`````````!@```````!D`````````&0````````!"0```````
M`````````````0```````````````%P````!``````````8```````!;0```
M`````%M``````````Y`````````````````````(``````````````!H````
M`0`````````&````````7M````````!>T`````````!$````````````````
M````"```````````````;@````$``````````@```````%\@````````7R``
M```````_@````````````````````!```````````````'8````!````````
M``(```````">H````````)Z@`````````!P````````````````````!````
M``````````!^`````0`````````#```````!G]P```````"?W``````````$
M````````````````````!```````````````B`````$``````````P``````
M`9_@````````G^``````````$`````````````````````@`````````````
M`(\````!``````````,```````&?\````````)_P`````````!``````````
M```````````(``````````````"6`````0`````````#```````!H```````
M``"@``````````!0````````````````````$```````````````G`````$`
M`````````P```````:!0````````H%``````````"```````````````````
M``@``````````````*4````!`````!````,```````&@8````````*!@````
M`````R@````````````````````0``````````@```"J`````0`````0```#
M```````!HX@```````"CB``````````(````````````````````"```````
M````````L0````@``````````P```````:.0````````HY`````````08```
M`````````````````!```````````````+8````!`````````#``````````
M`````````*.0`````````#$````````````````````!``````````$```"_
M`````0````````````````````````````"CQ`````````-`````````````
M````````!```````````````Q&____4`````````````````````````````
MIP0`````````$`````````````````````$```````````````$````#````
M`````````````````````````*<4`````````-0````````````````````!
(````````````
